@@ -64,7 +64,6 @@ def _retrieve_values(ini_path: str) -> List[str]:
     return out
 
 
-
 # installation path for ChemStation
 CHEMSTATION_INSTALL_PATH: pathlib.Path = pathlib.Path(
     _retrieve_value(
@@ -86,12 +85,12 @@ CHEMSTATION_CORE_PATH: pathlib.Path = pathlib.Path(
 logger.debug(f'core path: {CHEMSTATION_CORE_PATH}')
 
 # paths for HPLC data storage
-try:
+if _result:
     CHEMSTATION_DATA_PATHS: List[pathlib.Path] = [
         pathlib.Path(path)
         for path in _retrieve_values('_DATAPATH$')
     ]
-except configparser.NoOptionError:
+else:
     CHEMSTATION_DATA_PATHS = [pathlib.Path(_retrieve_value(
         ('PCS,1', '_DATAPATH$'),
         'hplcfolder',
