@@ -708,13 +708,17 @@ class DADSignal(DADSignalInfo):
         """
         return [list(line) for line in self.as_iterable_data_table()]
 
-    def write_signal_to_csv(self, filename: str) -> str:
+    def write_signal_to_csv(self, filename: str, overwrite: bool = False) -> str:
         """
         Writes the signal intensities to the specified csv file.
 
         :param filename: file name to write to
+        :param overwrite: whether to overwrite the file if it already exists
         :return: file path that was written
         """
+        # if the file already exists and overwrite was not specified, return
+        if os.path.isfile(filename) and overwrite is False:
+            return
         with open(filename, 'wt') as f:
             for line in self.as_iterable_data_table():
                 f.write(",".join([str(val) for val in line]))
@@ -801,12 +805,17 @@ class HPLCSample(HPLCSampleInfo):
         self.signals.append(new_signal)
         return new_signal
 
-    def write_signals_to_csv(self, directory: Union[str, pathlib.Path] = None) -> List[str]:
+    def write_signals_to_csv(self,
+                             directory: Union[str, pathlib.Path] = None,
+                             overwrite: bool = False
+                             ) -> List[str]:
         """
         Writes the signals to csv in the directory specified. If no directory is specified, the csv files will be
         written to the directory path specified in the directory attribute of the instance.
 
         :param directory: directory path
+        :param overwrite: whether to overwrite files if they already exist
+        :return: file paths written
         """
         if directory is None:
             if self.directory is None:
@@ -817,9 +826,11 @@ class HPLCSample(HPLCSampleInfo):
         for signal in self.signals:
             file_name = directory / f'{signal}.csv'
             signal.write_signal_to_csv(
-                file_name
+                file_name,
+                overwrite=overwrite,
             )
-            written_paths.append(str(file_name))
+            if file_name is not None:  # if a file was written
+                written_paths.append(str(file_name))
         # write TAC
         tac_file_name = directory / 'Total Absorbance Chromatogram.csv'
         written_paths.append(str(tac_file_name))
